
Soleil is a Python object configuration mechanism inspired by [Meta's Hydra](https://hydra.cc/). It's main goal is to provide a Python mechanism for machine learning researchers to assemble flexible experiments in a way that is **declarative**, **inheritable**, **automatically CLI-invokable** and **intuitively overridable**.

* Install soleil using

```
pip install soleil
```


* See [Soleil's full documentation](https://soleil.readthedocs.io/en/latest/) for more information


* Contribute at [Soleil's github page](https://github.com/zepedaj/soleil)


